@@ -31,6 +31,7 @@
 #include "StringMsg.h"
 
 #include "SDL.h"
+#include <stdio.h> // for fflush, stdout
 
 //-----------------------------------------------------------------
 Application::Application()
@@ -133,6 +134,8 @@ Application::prepareOptions(int argc, char *argv[])
             "Path to the worldmap file");
     params.addParam("cache_images", OptionParams::TYPE_BOOLEAN,
             "Cache images (default=true)");
+    params.addParam("sound_frequency", OptionParams::TYPE_NUMBER,
+            "Sound sample rate (default=44100)");
     OptionAgent::agent()->parseCmdOpt(argc, argv, params);
 }
 //-----------------------------------------------------------------
@@ -212,6 +215,9 @@ Application::receiveSimple(const SimpleMsg *msg)
             OptionAgent::agent()->setParam("loglevel", level);
         }
     }
+    else if (msg->equalsName("flush_stdout")) {
+        fflush(stdout);
+    }
     else {
         LOG_WARNING(ExInfo("unknown msg")
                 .addInfo("msg", msg->toString()));
