@@ -14,6 +14,7 @@ class SDLSoundAgent : public SoundAgent {
     private:
     static BaseMsg *ms_finished;
     Mix_Music *m_music;
+    std::string m_playingPath;
     int m_soundVolume;
 
     private:
@@ -24,6 +25,7 @@ class SDLSoundAgent : public SoundAgent {
     protected:
         virtual void own_init();
         virtual void own_shutdown();
+        virtual void reinit();
 
         virtual void setSoundVolume(int volume);
         virtual void setMusicVolume(int volume);
